package App::samesize ; 
our $VERSION = '0.017' ; 
our $DATE = '2023-03-23T22:30+09:00' ; 

=encoding utf8

=head1 NAME

App::samesize -- 現行ディレクトリにある全く同じバイトサイズのファイルを一覧にする。MD5ハッシュ値を使うオプションもある。

=head1 SYNOPSIS

This module provides a Unix-like command `F<samesize>'.

=head1 DESCRIPTION


=head1 AUTHOR

下野寿之 Toshiyuki SHIMONO <bin4tsv@gmail.com> 

=head1 COPYRIGHT AND LICENSE

Copyright (c) 2019-2023 Toshiyuki SHIMONO. All rights reserved.
This program is free software; you can redistribute it and/or
modify it under the same terms as Perl itself.

=cut

1 ;
